==> querydsl-parser-0.2-sources.jar: foundation/jpa/querydsl/StateRPar8.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar8 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>>> {

// NoStack:
// Stack:
    public StateRPar8(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<com.querydsl.core.types.Expression>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return Arrays.asList(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}

==> querydsl-parser-0.7-sources.jar: foundation/jpa/querydsl/StateRPar8.java <==
package foundation.jpa.querydsl;

import foundation.rpg.parser.UnexpectedInputException;
import foundation.rpg.parser.Named;

import java.util.Arrays;
import java.util.List;

// Generated visitor pattern based state for grammar parser.
public class StateRPar8 extends StackState<foundation.rpg.common.symbols.RPar, StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>>> {

// NoStack:
// Stack:
    public StateRPar8(foundation.jpa.querydsl.QueryFactory factory, foundation.rpg.common.symbols.RPar node, StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> prev) {
        super(factory, node, prev);
    }


// Reduce:
    @Override
    public State visitRPar(foundation.rpg.common.symbols.RPar symbol) throws UnexpectedInputException {
        StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitRPar(symbol);
    }

    @Override
    public State visitOr(foundation.rpg.common.symbols.Or symbol) throws UnexpectedInputException {
        StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitOr(symbol);
    }

    @Override
    public State visitAnd(foundation.rpg.common.symbols.And symbol) throws UnexpectedInputException {
        StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return stack5.visitRelationalBooleanExpression(getFactory().is(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode())).visitAnd(symbol);
    }


// Shift:
// Accept:
    @Override
    public List<Object> stack() {
        StackState<java.util.List<java.lang.Object>, StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>>> stack1 = this.getPrev();
		StackState<foundation.rpg.common.symbols.LPar, StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>>> stack2 = stack1.getPrev();
		StackState<foundation.rpg.common.symbols.In, StackState<com.querydsl.core.types.Expression, ? extends State>> stack3 = stack2.getPrev();
		StackState<com.querydsl.core.types.Expression, ? extends State> stack4 = stack3.getPrev();
		State stack5 = stack4.getPrev();
        return Arrays.asList(stack4.getNode(), stack3.getNode(), stack2.getNode(), stack1.getNode(), this.getNode());
    }

}
